@@ -1686,6 +1686,7 @@ def find(models, data_specs, X, y, args):
   dict_columns.append("model_ordr")
   dict_columns.extend(dict_performa_infos.keys())
   dict_columns.remove("model_idnm")
+  dict_columns.remove("model_init")
   dict_columns.remove("model_objt")
   #-------------------------------#
   df_models_infos = pd.DataFrame(dict_models_infos)
@@ -1790,7 +1791,6 @@ def auto_ml_train(df: None, args):
     drop_rows = args['mode_pres_drop_rows']
 
     df_tmp = df
-    print("hereee")
     df_tmp = load_data(df_tmp, args)
     df_tmp = drop_xxxs(df_tmp, drop_cols, 1, args)
     df_tmp = drop_xxxs(df_tmp, drop_rows, 0, args)
@@ -1829,4 +1829,4 @@ def auto_ml_pred(df: None, args, model_args):
     #Pred Method
     model = model_args["model"]
     y_hat, y_act = pred(model, X, y, args)
-    return y_hat, y_act
\ No newline at end of file
+    return y_hat, y_act
